@@ -23,13 +23,13 @@
     <name>GameoverBlurEffectWidget</name>
     <message>
         <location filename="../src/source/gameoverblureffectwidget.cpp" line="93"/>
-        <source>Play Again</source>
-        <translation>再來一局</translation>
+        <source> Play Again </source>
+        <translation> 再來一局 </translation>
     </message>
     <message>
         <location filename="../src/source/gameoverblureffectwidget.cpp" line="94"/>
-        <source>Have a Rest</source>
-        <translation>休息一下</translation>
+        <source> Have a Rest </source>
+        <translation> 休息一下 </translation>
     </message>
 </context>
 <context>
@@ -51,22 +51,22 @@
     <name>MainPage</name>
     <message>
         <location filename="../src/source/mainpage.cpp" line="32"/>
-        <source>Easy</source>
-        <translation>初級</translation>
+        <source> Easy </source>
+        <translation> 初級 </translation>
     </message>
     <message>
         <location filename="../src/source/mainpage.cpp" line="33"/>
-        <source>Normal</source>
-        <translation>中級</translation>
+        <source> Normal </source>
+        <translation> 中級 </translation>
     </message>
     <message>
         <location filename="../src/source/mainpage.cpp" line="34"/>
-        <source>Hard</source>
-        <translation>進階</translation>
+        <source> Hard </source>
+        <translation> 進階 </translation>
     </message>
     <message>
         <location filename="../src/source/mainpage.cpp" line="52"/>
-        <source>Select Level</source>
+        <source> Select Level </source>
         <translation>難度選擇</translation>
     </message>
 </context>
@@ -79,8 +79,8 @@
     </message>
     <message>
         <location filename="../src/source/mainwindow.cpp" line="100"/>
-        <source>VICTORY</source>
-        <translation>您贏了！！</translation>
+        <source> VICTORY </source>
+        <translation> 您贏了！ </translation>
     </message>
 </context>
 </TS>
